summaryrefslogtreecommitdiff
path: root/src/char/fwd.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/char/fwd.hpp')
-rw-r--r--src/char/fwd.hpp14
1 files changed, 13 insertions, 1 deletions
diff --git a/src/char/fwd.hpp b/src/char/fwd.hpp
index ff2bf22..8086083 100644
--- a/src/char/fwd.hpp
+++ b/src/char/fwd.hpp
@@ -22,6 +22,7 @@
#include "../ints/fwd.hpp" // rank 1
#include "../strings/fwd.hpp" // rank 1
+#include "../compat/fwd.hpp" // rank 2
#include "../generic/fwd.hpp" // rank 3
#include "../io/fwd.hpp" // rank 4
#include "../net/fwd.hpp" // rank 5
@@ -34,5 +35,16 @@
namespace tmwa
{
-// meh, add more when I feel like it
+namespace char_
+{
+ struct CharConf;
+ struct CharLanConf;
+ struct InterConf;
+
+ struct AuthFifoEntry;
+ struct mmo_map_server;
+
+ struct accreg;
+ // meh, add more when I feel like it
+} // namespace char_
} // namespace tmwa